@@ -40,6 +40,7 @@ CScoresheet::CScoresheet(QWidget *win_)
 	portrait = false;
 	loadingFile = false;
 	defaultName = "Player ";
+	defaultDirectory = "/home/user/MyDocs";
 	
 	for(int i=0; i<sizeX; i++)
 	{
@@ -198,12 +199,6 @@ CScoresheet::CScoresheet(QWidget *win_)
 	QLabel *aboutl = new QLabel("Scoresheet version "+VERSION+" by Heikki Holstila",dlg_about);
 	abt_hbox->addWidget(aboutl);
 
-	dlg_file = new QFileDialog(win, Qt::Dialog);
-	dlg_file->setViewMode(QFileDialog::List);
-	dlg_file->setDirectory("/home/user/MyDocs");
-	dlg_file->setNameFilter("Values (*.csv)");
-	dlg_file->setDefaultSuffix("csv");
-	
 	progress = new QProgressBar(win);
 	vbox->addWidget(progress);
 	progress->hide();
@@ -498,16 +493,17 @@ void CScoresheet::createSetup()
 
 void CScoresheet::save()
 {
-	dlg_file->setWindowTitle("Save file");
-	dlg_file->setFileMode(QFileDialog::AnyFile);
-	dlg_file->setAcceptMode(QFileDialog::AcceptSave);
+	QString fname = QFileDialog::getSaveFileName(win, "Save file",
+		defaultDirectory, "Comma Separated Values (*.csv)");
+		
+	if( fname!=NULL && !fname.endsWith(".csv") )
+		fname.append(".csv");
 	
 	QStringList fileNames;
-	if( dlg_file->exec() )
+	if( fname != NULL  )
 	{
-		fileNames = dlg_file->selectedFiles();
-
-		CCSVFile csv( fileNames.at(0) );
+		CCSVFile csv( fname );
+		
 		csv.appendRow(names);
 
 		QStringList row;		
@@ -535,16 +531,12 @@ void CScoresheet::save()
 
 void CScoresheet::load()
 {
-	dlg_file->setWindowTitle("Load file");
-	dlg_file->setFileMode(QFileDialog::ExistingFile);
-	dlg_file->setAcceptMode(QFileDialog::AcceptOpen);
-	
-	QStringList fileNames;
-	if( dlg_file->exec() )
-	{
-		fileNames = dlg_file->selectedFiles();
+	QString fname = QFileDialog::getOpenFileName(win, "Load file",
+		defaultDirectory, "Comma Separated Values (*.csv)");
 
-		CCSVFile csv( fileNames.at(0) );
+	if( fname != NULL )
+	{
+		CCSVFile csv( fname );
 		
 		if( !csv.load() ) {
 			QMaemo5InformationBox::information ( win, "Could not load file!",
